==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/languages/nn.php <==
<?php

return [
    'Names' => [
        'alt' => 'sør-altaj',
        'ang' => 'gammalengelsk',
        'asa' => 'asu (Tanzania)',
        'bas' => 'basa',
        'be' => 'kviterussisk',
        'bez' => 'bena (Tanzania)',
        'bss' => 'bakossi',
        'car' => 'carib',
        'ceb' => 'cebuano',
        'chg' => 'tsjagataisk',
        'chr' => 'cherokee',
        'ckb' => 'sorani',
        'crs' => 'seselwa (fransk-kreolsk)',
        'cu' => 'kyrkjeslavisk',
        'cv' => 'tsjuvansk',
        'den' => 'slavej',
        'dsb' => 'lågsorbisk',
        'ebu' => 'embu',
        'egy' => 'gammalegyptisk',
        'elx' => 'elamite',
        'fil' => 'filippinsk',
        'fro' => 'gammalfransk',
        'frs' => 'austfrisisk',
        'fur' => 'friulisk',
        'gil' => 'gilbertese',
        'gmh' => 'mellomhøgtysk',
        'goh' => 'gammalhøgtysk',
        'grc' => 'gammalgresk',
        'gv' => 'manx',
        'gwi' => 'gwichin',
        'hsb' => 'høgsorbisk',
        'kl' => 'grønlandsk (kalaallisut)',
        'krc' => 'karachay-balkar',
        'kum' => 'kumyk',
        'lad' => 'ladino',
        'lez' => 'lezghian',
        'li' => 'limburgisk',
        'lrc' => 'nord-lurisk',
        'lus' => 'lushai',
        'luy' => 'olulujia',
        'mdf' => 'moksha',
        'mfe' => 'morisyen',
        'mg' => 'madagassisk',
        'mzn' => 'mazanderani',
        'nds' => 'lågtysk',
        'ne' => 'nepalsk',
        'niu' => 'niuisk',
        'nog' => 'nogai',
        'non' => 'gammalnorsk',
        'nqo' => 'n’ko',
        'nso' => 'nordsotho',
        'nwc' => 'klassisk newarisk',
        'pcm' => 'nigeriansk pidgin',
        'peo' => 'gammalpersisk',
        'pro' => 'gammalprovençalsk',
        'quc' => 'k’iche',
        'rup' => 'arumensk',
        'rw' => 'kinjarwanda',
        'sc' => 'sardinsk',
        'sga' => 'gammalirsk',
        'srn' => 'sranan tongo',
        'st' => 'sørsotho',
        'swb' => 'shimaore',
        'syr' => 'syrisk',
        'tiv' => 'tivi',
        'tkl' => 'tokelau',
        'tn' => 'tswana',
        'tog' => 'tonga (Nyasa)',
        'tvl' => 'tuvalu',
        'tyv' => 'tuvinisk',
        'tzm' => 'sentral-tamazight',
        'udm' => 'udmurt',
        'war' => 'waray',
        'xal' => 'kalmykisk',
        'zap' => 'zapotec',
        'zbl' => 'blissymbol',
        'zgh' => 'standard marokkansk tamazight',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'ar_001' => 'moderne standardarabisk',
        'fa_AF' => 'dari',
        'nds_NL' => 'lågsaksisk',
        'nl_BE' => 'flamsk',
        'ro_MD' => 'moldavisk',
        'zh_Hans' => 'forenkla kinesisk',
        'zh_Hant' => 'tradisjonell kinesisk',
    ],
];

==> symfony_5.4.23+dfsg.orig.tar.xz: symfony-5.4.23/src/Symfony/Component/Intl/Resources/data/languages/nn.php <==
<?php

return [
    'Names' => [
        'alt' => 'sør-altaj',
        'ang' => 'gammalengelsk',
        'asa' => 'asu (Tanzania)',
        'bas' => 'basa',
        'be' => 'kviterussisk',
        'bez' => 'bena (Tanzania)',
        'bss' => 'bakossi',
        'car' => 'carib',
        'chg' => 'tsjagataisk',
        'chr' => 'cherokee',
        'ckb' => 'sorani',
        'crj' => 'sørleg aust-cree',
        'crl' => 'nordleg aust-cree',
        'crs' => 'seselwa (fransk-kreolsk)',
        'cu' => 'kyrkjeslavisk',
        'cv' => 'tsjuvansk',
        'den' => 'slavej',
        'dsb' => 'lågsorbisk',
        'ebu' => 'embu',
        'egy' => 'gammalegyptisk',
        'elx' => 'elamite',
        'fil' => 'filippinsk',
        'fro' => 'gammalfransk',
        'frs' => 'austfrisisk',
        'fur' => 'friulisk',
        'gil' => 'gilbertese',
        'gmh' => 'mellomhøgtysk',
        'goh' => 'gammalhøgtysk',
        'grc' => 'gammalgresk',
        'gv' => 'manx',
        'gwi' => 'gwichin',
        'hax' => 'sørleg haida',
        'hsb' => 'høgsorbisk',
        'ikt' => 'vestleg kanadisk inuktitut',
        'kl' => 'grønlandsk (kalaallisut)',
        'krc' => 'karachay-balkar',
        'kum' => 'kumyk',
        'lad' => 'ladino',
        'lez' => 'lezghian',
        'li' => 'limburgisk',
        'lrc' => 'nord-lurisk',
        'lus' => 'lushai',
        'luy' => 'olulujia',
        'mdf' => 'moksha',
        'mfe' => 'morisyen',
        'mg' => 'madagassisk',
        'mzn' => 'mazanderani',
        'nds' => 'lågtysk',
        'ne' => 'nepalsk',
        'niu' => 'niuisk',
        'nog' => 'nogai',
        'non' => 'gammalnorsk',
        'nqo' => 'n’ko',
        'nso' => 'nordsotho',
        'nwc' => 'klassisk newarisk',
        'ojb' => 'nordvestleg ojibwa',
        'ojw' => 'vestleg ojibwa',
        'pcm' => 'nigeriansk pidgin',
        'peo' => 'gammalpersisk',
        'pro' => 'gammalprovençalsk',
        'quc' => 'k’iche',
        'rup' => 'arumensk',
        'rw' => 'kinjarwanda',
        'sc' => 'sardinsk',
        'sga' => 'gammalirsk',
        'slh' => 'sørleg lushootseed',
        'srn' => 'sranan tongo',
        'st' => 'sørsotho',
        'swb' => 'shimaore',
        'syr' => 'syrisk',
        'tce' => 'sørleg tutchone',
        'tiv' => 'tivi',
        'tkl' => 'tokelau',
        'tn' => 'tswana',
        'tog' => 'tonga (Nyasa)',
        'ttm' => 'nordleg tutchone',
        'tvl' => 'tuvalu',
        'tyv' => 'tuvinisk',
        'tzm' => 'sentral-tamazight',
        'udm' => 'udmurt',
        'war' => 'waray',
        'xal' => 'kalmykisk',
        'zap' => 'zapotec',
        'zbl' => 'blissymbol',
        'zgh' => 'standard marokkansk tamazight',
        'zza' => 'zaza',
    ],
    'LocalizedNames' => [
        'nds_NL' => 'lågsaksisk',
        'ro_MD' => 'moldavisk',
        'zh_Hans' => 'forenkla kinesisk',
    ],
];
